package unicrawler.types;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import unicrawler.config.CrawlerConfig;
import unicrawler.parser.HyperlinkParser;
import unicrawler.utils.UrlUtils;

public class Page {
	private CrawlerConfig mConfig;
	
	private URL mUrl;
	private byte[] mPageContent;
	
	private int mRespCode;
	private long mRespTime;
	
	private String mCharset;
	
	private List<String> mPageLinks;
	private Map<String,String> mHeaders;
	
	public Page(CrawlerConfig _config, URL _url, byte[] _content, int _respCode, long _respTime, String _charset, Map<String,String> _headers) {
		this.mUrl = _url;
		this.mPageContent = _content;
		this.mRespCode  = _respCode;
		this.mRespTime = _respTime;
		this.mCharset = _charset;
		this.mHeaders = _headers;
		
		this.mConfig = _config;
		
		this.mPageLinks = new ArrayList<String>();
	}
	
	public void setServerHeaders(Map<String, String> _headers) {
		this.mHeaders = _headers;
	}
	
	public void parsePageLinks(String parentUrl) {
		this.mPageLinks.addAll(new HyperlinkParser(new String(this.mPageContent), parentUrl, this.mCharset).harvest());
	}
	
	public CrawlerURL getRedirectUrl(int depth) {
		if (this.mRespCode >= 300 && this.mRespCode < 400) {
			String link = this.mHeaders.get("Location");
			
			if (link == null) {
				// We were unable to follow this redirect!
				return null;
			}
			
			link = UrlUtils.resolveUrl(this.mUrl.toString(), link);
			
			//System.out.println("Redirect from [" + this.mUrl.toString() + "] => [" + link + "]");
			
			return new CrawlerURL(link, depth);
		}
		
		return null;
	}
	
	/* GET METHODS */
	public URL getPageUrl() {
		return this.mUrl;
	}
	
	public byte[] getPageContent() {
		return this.mPageContent;
	}
	
	public String getPageContentStr() {
		return new String(this.mPageContent);
	}
	
	public String getPageCharset() {
		return this.mCharset;
	}
	
	public int getPageResponseCode() {
		return this.mRespCode;
	}
	
	public long getPageResponseTime() {
		return this.mRespTime;
	}
	
	public List<String> getPageLinks() {
		return this.mPageLinks;
	}
	
	public void setPageLinks(List<String> _links) {
		this.mPageLinks = _links;
	}
}
